<?php
//============================================================================
//
//	Site:			mssv.net/wiki
//	File Name:		index.php
//	Author:			Richard L. Parker
//	Date:			07/06/13
//
//	Description:
//
//		This file redirects requests to the new wiki at mefiwiki.com.
//
//	Instructions:
//   
//      1) Rename MediaWiki's "index.php" file.
//		2) Put this file in the location of the original "index.php" file. 
//		3) Test that it correctly redirects various URL types to the new wiki.
//		4) If everything works OK change "Test_Mode" to FALSE.
//
//  License: 
//
//		Creative Commons Attribution 3.0 United States
//		http://creativecommons.org/licenses/by/3.0/us/
//
// ---------------------------------------------------------------------------
//							R E V I S I O N   H I S T O R Y
// ---------------------------------------------------------------------------
//
//	Date		Time	Description
//	--------	-----	-----------------------------------------------------
//	07/06/13	11:00	Initial implementation
//	07/06/13	12:15	Added support for MediaWiki "Short URL" configuration
//	07/07/13	02:10	Minor cleanup and formatting.
//
//============================================================================

// calling header() after any output (including blank lines from includes) will
// result in failure unless we use output buffering to defer the HTTP body
ob_start();

//-----------------------------------------------------------------------------
// CONSTANTS
//-----------------------------------------------------------------------------

// Behavior flags
define("Test_Mode",				TRUE); // Enable when testing to avoid URL caching.

// URLs for redirect
define("Dest_Host",				"http://mefiwiki.com");
define("Dest_URL_Default",		Dest_Host . "/wiki/");
define("Dest_URL_Article", 		Dest_Host . "/wiki");
define("Dest_URL_Query", 		Dest_Host . "/w/index.php");


//-----------------------------------------------------------------------------
// PRIVATE FUNCTIONS
//-----------------------------------------------------------------------------

// Report that an object has permanently moved to a new location
function Permanent_Redirect($url)
{
	header("HTTP/1.0 301 Moved Permanently");
	header("Location: " . $url);
	print "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML 2.0//EN\">\n";
	print "<html><head>\n";
	print "<title>301 Moved Permanently</title>\n";
	print "</head><body>\n";
	print "<h1>Moved Permanently</h1>\n";
	print "<p>The document has moved <a href=\"" . htmlspecialchars($url, ENT_QUOTES) . "\">here</a>.</p>\n";
	print "</body></html>\n";
}

// Report that an object has temporarily moved to a new location
function Temporary_Redirect($url)
{
	header("HTTP/1.0 302 Moved Temporarily");
	header("Location: " . $url);
	print "<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML 2.0//EN\">\n";
	print "<html><head>\n";
	print "<title>302 Moved Temporarily</title>\n";
	print "</head><body>\n";
	print "<h1>Moved Temporarily</h1>\n";
	print "<p>The document has moved <a href=\"" . htmlspecialchars($url, ENT_QUOTES) . "\">here</a>.</p>\n";
	print "</body></html>\n";
}

// Get path string (if any)
function GetPathString()
{
	$path = "";
	if ((isset($_SERVER['PATH_INFO'])) && (!empty($_SERVER['PATH_INFO'])))
	{
		$path = $_SERVER['PATH_INFO'];
	}
	return $path;
}

// Get query string (if any)
function GetQueryString()
{
	$query = "";
	if ((isset($_SERVER['QUERY_STRING'])) && (!empty($_SERVER['QUERY_STRING'])))
	{
		$query = "?" . $_SERVER['QUERY_STRING'];
	}
	return $query;
}

// Get the URL on the new wiki that corresponds to URL requested from the old wiki
function GetDestinationURL()
{
	$path = GetPathString();
	$query = GetQueryString();
	
	if (empty($path) && empty($query))
	{
		// If requested URL is not an article or a query, destination is the default URL.
		$url = Dest_URL_Default;
	}
	else
	{
		if (empty($query))
		{
			// If requested URL isn't a query, destination URL is an article URL.
			$url = Dest_URL_Article . $path;
		}
		else
		{
			// Otherwise we have a query URL, so destination URL is also a query.
			$url = Dest_URL_Query . $path . $query;
		}
	}
	
	return $url;
}


//-----------------------------------------------------------------------------
// MAIN
//-----------------------------------------------------------------------------

// Either temporarily or permanently redirect to new URL based on whether or not
// we're in testing mode.
$url = GetDestinationURL();
if (Test_Mode)
{
	Temporary_Redirect($url);
}
else
{
	Permanent_Redirect($url);
}

// Flush our output buffers (ensures that headers preceed any page content).
ob_end_flush();

?>